@@ -169,7 +169,7 @@ void REXP_joint( RMatrix &ddata,  RVector &marker, double trait, double env,  do
         if( d(i, C_FATH)==0 && d(i, C_MOTH)==0 ) {
           // it's a parent
           if( curP>1 ) {
-            Rprintf("Too many parents in family %d, ignoring parents 3 and higher.\n", d(i,C_PID));
+            Rprintf("Too many parents in family %d, ignoring parents 3 and higher.\n", (int)d(i,C_PID));
           }else{
             if( curP==0 ) {
               p1[0] = (int)d(i,m0);
